0.2.22 (2023-09-18)
-------------------

Resolved a significant bug in theme selection. If you picked a theme
stored in your session, the system would mistakenly apply a pre-selected
theme for HTML fragments rendered through the JSON API. This was due
to the real theme choice not being correctly passed from the JSON API
to the Wagtail page, resulting in a completely dysfunctional Vue theme.

- Bugfix theme selection #105
- Fixed mypy issues by django-stubs update + one small fix #101
- Improved documentation for theme selection #105
- Got rid of ProxyRequest in favor of a simple HtmlField #105
- Fixed searching for name instead of slug when filtering tags #100
- Added a `has_selectable_themes` flag to the context of blog pages to make it easy to decide whether a theme selector can be showed #105
